==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/ArrowUpFromWaterPump.md <==
# ArrowUpFromWaterPump


```text
fontawesome-6/Solid/ArrowUpFromWaterPump
```

```text
include('fontawesome-6/Solid/ArrowUpFromWaterPump')
```



| Illustration | ArrowUpFromWaterPump |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/ArrowUpFromWaterPump.png) | ![illustration for ArrowUpFromWaterPump](../../fontawesome-6/Solid/ArrowUpFromWaterPump.Local.png) |




## ArrowUpFromWaterPump

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element ArrowUpFromWaterPump
include('fontawesome-6/Solid/ArrowUpFromWaterPump')

' renders the element
ArrowUpFromWaterPump('ArrowUpFromWaterPump', 'Arrow Up From Water Pump', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element ArrowUpFromWaterPump
include('fontawesome-6/Solid/ArrowUpFromWaterPump')

' renders the element
ArrowUpFromWaterPump('ArrowUpFromWaterPump', 'Arrow Up From Water Pump', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Solid/ArrowUpFromWaterPump.md <==
# ArrowUpFromWaterPump


```text
fontawesome-6/Solid/ArrowUpFromWaterPump
```

```text
include('fontawesome-6/Solid/ArrowUpFromWaterPump')
```



| Illustration | ArrowUpFromWaterPump |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/ArrowUpFromWaterPump.png) | ![illustration for ArrowUpFromWaterPump](../../fontawesome-6/Solid/ArrowUpFromWaterPump.Local.png) |




## ArrowUpFromWaterPump

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element ArrowUpFromWaterPump
include('fontawesome-6/Solid/ArrowUpFromWaterPump')

' renders the element
ArrowUpFromWaterPump('ArrowUpFromWaterPump', 'Arrow Up From Water Pump', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element ArrowUpFromWaterPump
include('fontawesome-6/Solid/ArrowUpFromWaterPump')

' renders the element
ArrowUpFromWaterPump('ArrowUpFromWaterPump', 'Arrow Up From Water Pump', 'an optional tech label', 'an optional description')
@enduml
```
